==> com.liferay.site.cms.site.initializer-1.0.7.jar: META-INF/resources/js/index.ts <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

// Content Editor

export {default as ContentEditorManagementBar} from './content_editor/components/ContentEditorManagementBar';
export {default as ContentEditorSidePanel} from './content_editor/components/ContentEditorSidePanel';
export {default as SpaceList} from './content_editor/components/SpaceList';

// Main

export {default as AllFDSPropsTransformer} from './main/FDSPropsTransformer/AllFDSPropsTransformer';
export {default as AllSpacesFDSPropsTransformer} from './main/FDSPropsTransformer/AllSpacesFDSPropsTransformer';
export {default as CategoryFDSPropsTransformer} from './main/FDSPropsTransformer/CategoryFDSPropsTransformer';
export {default as CategoryUsagesFDSPropsTransformer} from './main/FDSPropsTransformer/CategoryUsagesFDSPropsTransformer';
export {default as ContentsFDSPropsTransformer} from './main/FDSPropsTransformer/ContentsFDSPropsTransformer';
export {default as FilesFDSPropsTransformer} from './main/FDSPropsTransformer/FilesFDSPropsTransformer';
export {default as StructureUsagesFDSPropsTransformer} from './main/FDSPropsTransformer/StructureUsagesFDSPropsTransformer';
export {default as StructuresFDSPropsTransformer} from './main/FDSPropsTransformer/StructuresFDSPropsTransformer';
export {default as TagUsagesFDSPropsTransformer} from './main/FDSPropsTransformer/TagUsagesFDSPropsTransformer';
export {default as VocabularyFDSPropsTransformer} from './main/FDSPropsTransformer/VocabularyFDSPropsTransformer';
export {default as CategorizationToolbar} from './main/categorization/CategorizationToolbar';
export {default as EditCategoryPage} from './main/categorization/categories/EditCategoryPage';
export {default as CategorizationBreadcrumb} from './main/categorization/components/CategorizationBreadcrumb';
export {default as ViewTags} from './main/categorization/tags/ViewTags';
export {default as EditVocabulary} from './main/categorization/vocabularies/EditVocabulary';
export {default as SpaceSticker} from './main/components/SpaceSticker';
export {default as EditFolder} from './main/components/folders/EditFolder';
export {default as ViewDashboard} from './main/dashboard/ViewDashboard';
export {default as NewSpace} from './main/spaces/NewSpace';
export {default as SpacesNavigation} from './main/spaces_navigation/SpacesNavigation';

// Structure Builder

export {default as StructureBuilder} from './structure_builder/components/StructureBuilder';
export {default as PicklistBuilder} from './structure_builder/components/picklist_builder/PicklistBuilder';

==> com.liferay.site.cms.site.initializer-1.0.9.jar: META-INF/resources/js/index.ts <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

// Content Editor

export {default as ContentEditorManagementBar} from './content_editor/components/ContentEditorManagementBar';
export {default as ContentEditorSidePanel} from './content_editor/components/ContentEditorSidePanel';
export {default as SpaceList} from './content_editor/components/SpaceList';

export {default as AllFDSPropsTransformer} from './main/FDSPropsTransformer/AllFDSPropsTransformer';
export {default as AllSpacesFDSPropsTransformer} from './main/FDSPropsTransformer/AllSpacesFDSPropsTransformer';
export {default as CategoryFDSPropsTransformer} from './main/FDSPropsTransformer/CategoryFDSPropsTransformer';
export {default as CategoryUsagesFDSPropsTransformer} from './main/FDSPropsTransformer/CategoryUsagesFDSPropsTransformer';
export {default as ContentsFDSPropsTransformer} from './main/FDSPropsTransformer/ContentsFDSPropsTransformer';
export {default as FilesFDSPropsTransformer} from './main/FDSPropsTransformer/FilesFDSPropsTransformer';
export {default as FolderFDSPropsTransformer} from './main/FDSPropsTransformer/FolderFDSPropsTransformer';
export {default as StructureUsagesFDSPropsTransformer} from './main/FDSPropsTransformer/StructureUsagesFDSPropsTransformer';
export {default as StructuresFDSPropsTransformer} from './main/FDSPropsTransformer/StructuresFDSPropsTransformer';
export {default as TagUsagesFDSPropsTransformer} from './main/FDSPropsTransformer/TagUsagesFDSPropsTransformer';
export {default as VocabularyFDSPropsTransformer} from './main/FDSPropsTransformer/VocabularyFDSPropsTransformer';
export {default as CategorizationToolbar} from './main/categorization/CategorizationToolbar';
export {default as EditCategoryPage} from './main/categorization/categories/EditCategoryPage';
export {default as CategorizationBreadcrumb} from './main/categorization/components/CategorizationBreadcrumb';
export {default as ViewTags} from './main/categorization/tags/ViewTags';
export {default as EditVocabulary} from './main/categorization/vocabularies/EditVocabulary';
export {default as BackButtonManagementBar} from './main/components/BackButtonManagementBar';
export {default as Breadcrumb} from './main/components/Breadcrumb';
export {default as SpaceAbstractHeader} from './main/components/SpaceAbstractHeader';
export {default as SpaceSticker} from './main/components/SpaceSticker';
export {default as EditFolder} from './main/components/folders/EditFolder';
export {default as AssetTypeInfoPanelContent} from './main/components/info_panel/AssetTypeInfoPanelContent';

export {default as ViewDashboard} from './main/dashboard/ViewDashboard';

// Main

export {default as AddSpaceMembers} from './main/spaces/AddSpaceMembers';
export {default as NewSpace} from './main/spaces/NewSpace';
export {default as SpaceSettings} from './main/spaces/SpaceSettings';
export {default as SpacesNavigation} from './main/spaces_navigation/SpacesNavigation';

// Structure Builder

export {default as StructureBuilder} from './structure_builder/components/StructureBuilder';
export {default as PicklistBuilder} from './structure_builder/components/picklist_builder/PicklistBuilder';
